@@ -1,7 +1,10 @@
+import os.path
+
 from django.shortcuts import render,reverse,HttpResponse
 import json
 import uuid
 from django.urls import reverse
+
 class web:
     #清洗文章把文章中的空格和换行符替换成html格式
     @classmethod
@@ -282,7 +285,24 @@ class spider_tools:
             if len(ret) == 1:continue
             headers[ret[0].strip()] = ret[1].strip()
         return headers
-
+    #格式化params 字符串为字典
+    @classmethod
+    def return_params(paramstr):
+        paramsdic = {}
+        for i in paramstr.split('&'):
+            ret = i.split('=')
+            print(ret)
+            paramsdic[ret[0]] = ret[1]
+        return paramsdic
+    # 格式化fiddler的请求头
+    @classmethod
+    def turn_fiddler_payload(cls,raw):
+        newdata = [ i.replace('        ','') for i in raw.split('\n') if len(i.replace('        ','')) >0]
+        payload ={}
+        for f in newdata:
+            fgdata = f.split('\t')
+            payload[fgdata[0]] = fgdata[1]
+        return  payload
     # 下载的标题特俗符号处理
     @classmethod
     def title_replace(cls,title):
@@ -335,6 +355,28 @@ class spider_tools:
     @classmethod
     def path_clean(self,path):
         return path.strip('\u202a')
+#加密解密相关
+class sign_tools:
+    @classmethod
+    def get_sign(cls,paragms,neadlist = [],deletelist = [],sign_and = '&',reverse = False):
+        '''
+        本方法用于加签时的排序，返回
+        :param paragms: 传入字典
+        :param neadlist: 需要的参数
+        :param deletelist: 要删除的参数
+        :param sign_and :链接 默认为 &
+        :param reverse = True 降序 ， reverse = False 升序
+        :return:
+        '''
+        new_paragms = {}
+        if len(neadlist) == 0 :
+            neadlist = paragms.keys()
+        for i in neadlist:
+            if i not in deletelist:
+                new_paragms[i] = paragms[i]
+        params_listjson = sorted(new_paragms.items(), key=lambda e: e[0],reverse = reverse)  # 参数字典倒排序为列表
+        sign = sign_and.join(f'{k}={v}' for k, v in params_listjson)
+        return sign
 #os的封装
 class dx_os:
     def __init__(self):pass
@@ -348,18 +390,161 @@ class dx_os:
         '''
         import os
         title_1ist = os.path.basename(path).split('.')
-        print(title_1ist)
         if len(title_1ist) > 1:  # 去掉后缀
             title_1ist.pop(-1)
             title = ''.join(title_1ist)
         else:
             title = os.path.basename(path)
         return title
-
+    #获得文件后缀
+    @classmethod
+    def get_file_houzhui(cls,path):
+        '''
+        :param path: 传入路径
+        :return:
+        '''
+        import os
+        houzhui  = path.split('.')[-1]
+        return houzhui
     #获得可保存的无特殊符号的文件名
     @classmethod
     def get_chunjingfilename(cls,file):
         ts = ['?',r'\n']
         for i in ts:
             file = file.replace(i,'')
-        return file
\ No newline at end of file
+        return file
+    #获得文件夹内所有文件的绝对路径，返回列表
+    def get_fold_file_absolute(self,path):
+        paths = os.walk(path)
+        pathlist = [i for i in paths]
+        newpathlist = [f'''{os.path.join(pathlist[0][0], i)}''' for i in pathlist[0][2]]
+        return newpathlist
+    #给文件随机重命名
+    @classmethod
+    def get_new_file_name(cls,filename):
+        import time
+        ext = filename.split('.')[-1]
+        filename = '{}.{}'.format(str(time.time()).split('.')[0], ext)
+        return filename
+    #设置快捷方式
+    @classmethod
+    def set_shortcut(cls,filename, lnkname, argumensts, startpath, iconname=''):  # 如无需特别设置图标，则可去掉iconname参数
+        '''
+
+        :param filename: 文件完整路径
+        :param lnkname: 快捷方式存放路径
+        :param argumensts: 参数 --user-data-dir=E:softwaregooglechromesgooglechrome4 多开
+        :param startpath: 开始位置
+        :param iconname: 图标路径
+        :return:
+        '''
+        import pythoncom
+        from win32com.shell import shell
+        from win32com.shell import shellcon
+        try:
+            # 将要在此路径创建快捷方式
+            shortcut = pythoncom.CoCreateInstance(
+                shell.CLSID_ShellLink, None,
+                pythoncom.CLSCTX_INPROC_SERVER, shell.IID_IShellLink)
+            shortcut.SetPath(filename)
+            shortcut.SetArguments(argumensts)
+            shortcut.SetWorkingDirectory(startpath)  # 设置快捷方式的起始位置, 不然会出现找不到辅助文件的情况
+            shortcut.SetIconLocation(iconname, 0)  # 可有可无，没有就默认使用文件本身的图标
+            if os.path.splitext(lnkname)[-1] != '.lnk':
+                lnkname += ".lnk"
+            shortcut.QueryInterface(pythoncom.IID_IPersistFile).Save(lnkname, 0)
+            return True
+        except Exception as e:
+            print(e.args)
+            return False
+    #设置快捷方式
+    @classmethod
+    def GetShortCut_path(cls,path):
+        import struct
+        target = ''
+        try:
+            with open(path, 'rb') as stream:
+                content = stream.read()
+
+                # skip first 20 bytes (HeaderSize and LinkCLSID)
+                # read the LinkFlags structure (4 bytes)
+                lflags = struct.unpack('I', content[0x14:0x18])[0]
+                position = 0x18
+
+                # if the HasLinkTargetIDList bit is set then skip the stored IDList
+                # structure and header
+                if (lflags & 0x01) == 1:
+                    position = struct.unpack('H', content[0x4C:0x4E])[0] + 0x4E
+
+                last_pos = position
+                position += 0x04
+
+                # get how long the file information is (LinkInfoSize)
+                length = struct.unpack('I', content[last_pos:position])[0]
+
+                # skip 12 bytes (LinkInfoHeaderSize, LinkInfoFlags, and VolumeIDOffset)
+                position += 0x0C
+
+                # go to the LocalBasePath position
+                lbpos = struct.unpack('I', content[position:position + 0x04])[0]
+                position = last_pos + lbpos
+
+                # read the string at the given position of the determined length
+                size = (length + last_pos) - position - 0x02
+                temp = struct.unpack('c' * size, content[position:position + size])
+                target = ''.join([chr(ord(a)) for a in temp])
+        except:
+            # could not read the file
+            pass
+
+        return target
+    #path方面
+    class path:
+        #获得桌面路径
+        @classmethod
+        def get_desk_path(cls):
+                return os.path.join(os.path.expanduser('~'), "Desktop")
+        #判断是否是lnk文件
+        @classmethod
+        def is_link(cls,path):
+            if path[-3:] == 'lnk':
+                return True
+            else:
+                return False
+#图像封装
+class dx_img:
+
+    #png转jpg
+    @classmethod
+    def png_jpg(cls,picpath,fold = False):
+        from PIL import Image
+        '''
+        
+        :param picpath: 要转换的图片
+        :param fold: 是否需要放到新的文件夹，默认是当前地址
+        :return: 成功返回新的地址  失败返回false
+        '''
+        img = Image.open(picpath)
+        if not fold:
+            newpath= os.path.join(os.path.dirname(picpath),f'''{dx_os.get_wuhouzhuifilename(picpath)}.jpg''')
+        else:
+            newpath = os.path.join(fold,f'''{dx_os.get_wuhouzhuifilename(picpath)}.jpg''')
+
+
+        try:
+            img.save(newpath)
+            return  newpath
+        except:
+            try:
+                img = img.convert('RGB')  # 1是以彩色图方式去读
+                # 存放虚假展示图片
+                img.save(newpath)
+
+                print(picpath, '转换成功！')
+        # 返回文件名
+                return newpath
+            except Exception as e:
+                print(e)
+                return False
+if __name__ == '__main__':
+    print(dx_img.png_jpg(r'G:\工作\爱赞助\QQ群基础文件\1_2.png'))
\ No newline at end of file
