@@ -1,8 +1,7 @@
 #winrar 路径
 winrarpath = 'C:\Program Files\WinRAR\WinRAR.exe'
 
-#压缩密码
-# password = '123456zxc'
+
 
 #分卷大小
 fenjuansize = '2g -v4g'
@@ -20,10 +19,22 @@ yasuo_after_delet = True
 #随机生成文件，防止压缩包md5相同
 suijishu = False
 
+other_add_file = [
+    r'F:\python\pyqt5\manager\winrar_yasuo\fujia\更多游戏下载.url',
+]
+other_add_file1= [
+    r'F:\python\pyqt5\manager\winrar_yasuo\path\更多人物卡下载.url',
+]
+
+
+#压缩密码
+# password = '123456zxc'
+# password1 = '123456zxc'
+password2 = '123456zxc'
 #自解压选择
 zijieya_text = [
-    ('comment.txt'),
-    ('comment_card.txt')
+    ('F:\python\pyqt5\pypi_update\src\zdxtools\winrar\comment.txt',other_add_file,password2),
+    ('F:\python\pyqt5\pypi_update\src\zdxtools\winrar\comment_card.txt',other_add_file1)
 ]
 
 
@@ -32,9 +43,7 @@ zijieya_text = [
 #     r'F:\python\pyqt5\tools\fujia\更多游戏下载.url',
 #
 # ]
-other_add_file = [
-    r'F:\python\pyqt5\manager\winrar_yasuo\fujia\更多游戏下载.url',
-]
+
 
 if __name__ == '__main__':
     import os
